import DiscRecording
from PyObjCTools.TestSupport import TestCase


class TestDRContentProperties(TestCase):
    def testConstants(self):
        self.assertIsInstance(DiscRecording.kDRISOLevel, str)
        self.assertIsInstance(DiscRecording.kDRVolumeSet, str)
        self.assertIsInstance(DiscRecording.kDRPublisher, str)
        self.assertIsInstance(DiscRecording.kDRDataPreparer, str)
        self.assertIsInstance(DiscRecording.kDRSystemIdentifier, str)
        self.assertIsInstance(DiscRecording.kDRApplicationIdentifier, str)
        self.assertIsInstance(DiscRecording.kDRCopyrightFile, str)
        self.assertIsInstance(DiscRecording.kDRAbstractFile, str)
        self.assertIsInstance(DiscRecording.kDRBibliographicFile, str)
        self.assertIsInstance(DiscRecording.kDRBlockSize, str)
        self.assertIsInstance(DiscRecording.kDRDefaultDate, str)
        self.assertIsInstance(DiscRecording.kDRVolumeCreationDate, str)
        self.assertIsInstance(DiscRecording.kDRVolumeModificationDate, str)
        self.assertIsInstance(DiscRecording.kDRVolumeCheckedDate, str)
        self.assertIsInstance(DiscRecording.kDRVolumeExpirationDate, str)
        self.assertIsInstance(DiscRecording.kDRVolumeEffectiveDate, str)
        self.assertIsInstance(DiscRecording.kDRISOMacExtensions, str)
        self.assertIsInstance(DiscRecording.kDRISORockRidgeExtensions, str)
        self.assertIsInstance(DiscRecording.kDRSuppressMacSpecificFiles, str)
        self.assertIsInstance(DiscRecording.kDRAllFilesystems, str)
        self.assertIsInstance(DiscRecording.kDRISO9660, str)
        self.assertIsInstance(DiscRecording.kDRISO9660LevelOne, str)
        self.assertIsInstance(DiscRecording.kDRISO9660LevelTwo, str)
        self.assertIsInstance(DiscRecording.kDRJoliet, str)
        self.assertIsInstance(DiscRecording.kDRHFSPlus, str)
        self.assertIsInstance(DiscRecording.kDRUDF, str)
        self.assertIsInstance(DiscRecording.kDRISO9660VersionNumber, str)
        self.assertIsInstance(DiscRecording.kDRInvisible, str)
        self.assertIsInstance(DiscRecording.kDRCreationDate, str)
        self.assertIsInstance(DiscRecording.kDRContentModificationDate, str)
        self.assertIsInstance(DiscRecording.kDRAttributeModificationDate, str)
        self.assertIsInstance(DiscRecording.kDRAccessDate, str)
        self.assertIsInstance(DiscRecording.kDRBackupDate, str)
        self.assertIsInstance(DiscRecording.kDRRecordingDate, str)
        self.assertIsInstance(DiscRecording.kDREffectiveDate, str)
        self.assertIsInstance(DiscRecording.kDRExpirationDate, str)
        self.assertIsInstance(DiscRecording.kDRPosixFileMode, str)
        self.assertIsInstance(DiscRecording.kDRPosixUID, str)
        self.assertIsInstance(DiscRecording.kDRPosixGID, str)
        self.assertIsInstance(DiscRecording.kDRHFSPlusTextEncodingHint, str)
        self.assertIsInstance(DiscRecording.kDRHFSPlusCatalogNodeID, str)
        self.assertIsInstance(DiscRecording.kDRMacFileType, str)
        self.assertIsInstance(DiscRecording.kDRMacFileCreator, str)
        self.assertIsInstance(DiscRecording.kDRMacWindowBounds, str)
        self.assertIsInstance(DiscRecording.kDRMacIconLocation, str)
        self.assertIsInstance(DiscRecording.kDRMacScrollPosition, str)
        self.assertIsInstance(DiscRecording.kDRMacWindowView, str)
        self.assertIsInstance(DiscRecording.kDRMacFinderFlags, str)
        self.assertIsInstance(DiscRecording.kDRMacExtendedFinderFlags, str)
        self.assertIsInstance(DiscRecording.kDRMacFinderHideExtension, str)
        self.assertIsInstance(DiscRecording.kDRUDFWriteVersion, str)
        self.assertIsInstance(DiscRecording.kDRUDFVersion102, str)
        self.assertIsInstance(DiscRecording.kDRUDFVersion150, str)
        self.assertIsInstance(DiscRecording.kDRUDFPrimaryVolumeDescriptorNumber, str)
        self.assertIsInstance(DiscRecording.kDRUDFVolumeSequenceNumber, str)
        self.assertIsInstance(DiscRecording.kDRUDFMaxVolumeSequenceNumber, str)
        self.assertIsInstance(DiscRecording.kDRUDFInterchangeLevel, str)
        self.assertIsInstance(DiscRecording.kDRUDFMaxInterchangeLevel, str)
        self.assertIsInstance(DiscRecording.kDRUDFApplicationIdentifierSuffix, str)
        self.assertIsInstance(DiscRecording.kDRUDFVolumeSetIdentifier, str)
        self.assertIsInstance(DiscRecording.kDRUDFVolumeSetTimestamp, str)
        self.assertIsInstance(DiscRecording.kDRUDFVolumeSetImplementationUse, str)
        self.assertIsInstance(DiscRecording.kDRUDFRealTimeFile, str)
        self.assertIsInstance(DiscRecording.kDRUDFExtendedFilePermissions, str)
